@@ -3,11 +3,12 @@ import os
 from PyQt5 import QtGui
 
 __base_dir__ = os.path.split(os.path.abspath(__file__))[0]
+__res_dir__ = os.path.join(__base_dir__, "resources")
 
 
 def load_icon(name: str) -> QtGui.QIcon:
     """
-    Load an icon from the base directory.
+    Load an icon from the 'resources' directory.
 
     Parameters
     ----------
@@ -19,4 +20,4 @@ def load_icon(name: str) -> QtGui.QIcon:
     QtGui.QIcon
         The loaded icon.
     """
-    return QtGui.QIcon(os.path.join(__base_dir__, name))
+    return QtGui.QIcon(os.path.join(__res_dir__, name))
