@@ -1,8 +1,15 @@
 from __future__ import annotations
 
+from pathlib import Path
+
+import xarray as xr
 from PyQt5 import QtWidgets
 from PyQt5.QtWidgets import QApplication
 from pyqtgraph.widgets import PlotWidget
+from quantify_core.data.handling import locate_experiment_container, DATASET_NAME
+from quantify_core.data.types import TUID
+
+from quantifiles.watcher import FileMonitor
 
 
 def set_label(
@@ -51,3 +58,23 @@ def copy_to_clipboard(widget: QtWidgets.QWidget) -> None:
     None
     """
     QApplication.clipboard().setImage(widget.grab().toImage())
+
+
+def get_file_monitor_for_dataset(dataset: xr.Dataset) -> FileMonitor:
+    """
+    Get a FileMonitor for a dataset.
+
+    Parameters
+    ----------
+    dataset : DataSet
+        The dataset to get a FileMonitor for.
+
+    Returns
+    -------
+    FileMonitor
+        The FileMonitor for the dataset.
+    """
+    tuid = TUID(dataset.attrs["tuid"])
+    directory = Path(locate_experiment_container(tuid))
+    monitor = FileMonitor(directory / DATASET_NAME)
+    return monitor
